//*************************************************************************
//     File : glsl.h - 15 Jun 2005
//  Purpose : GLSL utility functions
//
//   Author : Marco Benvegnu
//	          hiforce@gmx.it
//	          www.benve.org
//*************************************************************************

#ifndef _GLSL_H_
#define _GLSL_H_

#include "glew.h"
#include <stdio.h>

void glslPrintInfoLog(GLhandleARB obj)
{
	int infologLength = 0;

	glGetObjectParameterivARB(obj, GL_OBJECT_INFO_LOG_LENGTH_ARB, &infologLength);
	if (infologLength == 0) return;
	char *infoLog = new char[infologLength];
	glGetInfoLogARB(obj, infologLength, NULL, infoLog);
	printf(infoLog);
	delete infoLog;
}

void glslShaderSource(GLhandleARB shaderObj, const char *filename)
{
	FILE *f = NULL;
	int size;
	
	f = fopen(filename, "rt");
	if (!f) return;
	
	fseek(f, 0, SEEK_END);
	size = ftell(f);
	fseek(f, 0, SEEK_SET);
	
	char *text = new char[size];
	size = fread(text, 1, size, f);
	fclose(f);

	glShaderSourceARB(shaderObj, 1, (const char**)&text, &size);
}

// Set filename = NULL to use the fixed functionality
GLhandleARB glslLoadShaders(const char *vsFileName, const char *fsFileName)
{
	GLhandleARB p = glCreateProgramObjectARB();

	if (vsFileName)
	{
		GLhandleARB v = glCreateShaderObjectARB(GL_VERTEX_SHADER_ARB);
		glslShaderSource(v, vsFileName);
		glCompileShaderARB(v);
		glAttachObjectARB(p,v);
		glslPrintInfoLog(v);
	}

	if (fsFileName)
	{
		GLhandleARB f = glCreateShaderObjectARB(GL_FRAGMENT_SHADER_ARB);
		glslShaderSource(f, fsFileName);
		glCompileShaderARB(f);
		glAttachObjectARB(p,f);
		glslPrintInfoLog(f);
	}

	glLinkProgramARB(p);
	glslPrintInfoLog(p);
	return p;
}

#endif //_GLSL_H_
